@@ -362,7 +362,6 @@ _hal_drive_policy_get_display_name (GnomeVFSVolumeMonitorDaemon *volume_monitor_
 	/* drives we know the type of */
 	if (drive_type == LIBHAL_DRIVE_TYPE_CDROM) {
 		const char *first;
-		const char *sep;
 		const char *second;
 		LibHalDriveCdromCaps drive_cdrom_caps;
 			
@@ -374,8 +373,6 @@ _hal_drive_policy_get_display_name (GnomeVFSVolumeMonitorDaemon *volume_monitor_
 		if (drive_cdrom_caps & LIBHAL_DRIVE_CDROM_CAPS_CDRW)
 			first = _("CD-RW");
 		
-		sep = _("/");
-			
 		second = NULL;
 		if (drive_cdrom_caps & LIBHAL_DRIVE_CDROM_CAPS_DVDROM)
 			second = _("DVD-ROM");
@@ -396,7 +393,12 @@ _hal_drive_policy_get_display_name (GnomeVFSVolumeMonitorDaemon *volume_monitor_
 		    (drive_cdrom_caps & LIBHAL_DRIVE_CDROM_CAPS_DVDPLUSRW))
 			second = _("DVD±RW");
 
-		name = g_strdup_printf (_("%s%s%s Drive"), first, second != NULL ? sep : "", second);
+		if (second != NULL) {
+			name = g_strdup_printf (_("%s/%s Drive"), first, second);
+		} else {
+			name = g_strdup_printf (_("%s Drive"), first);
+		}
+			
 		may_prepend_external = TRUE;		
 	} else if (drive_type == LIBHAL_DRIVE_TYPE_FLOPPY) {
 		name = g_strdup (_("Floppy Drive"));
@@ -828,6 +830,7 @@ _hal_add_drive_without_volumes (GnomeVFSVolumeMonitorDaemon *volume_monitor_daem
 	drive->priv->is_user_visible = TRUE;
 	drive->priv->volumes = NULL;
 	drive->priv->hal_udi = g_strdup (libhal_drive_get_udi (hal_drive));
+        drive->priv->must_eject_at_unmount = libhal_drive_requires_eject (hal_drive);
 
 	_gnome_vfs_volume_monitor_connected (volume_monitor, drive);
 	gnome_vfs_drive_unref (drive);
@@ -915,6 +918,7 @@ _hal_add_volume (GnomeVFSVolumeMonitorDaemon *volume_monitor_daemon,
 		drive->priv->volumes = NULL;
 		drive->priv->hal_udi = g_strdup (libhal_volume_get_udi (hal_volume));
 		drive->priv->hal_drive_udi = g_strdup (libhal_drive_get_udi (hal_drive));
+                drive->priv->must_eject_at_unmount = libhal_drive_requires_eject (hal_drive);
 	
 		_gnome_vfs_volume_monitor_connected (volume_monitor, drive);
 		gnome_vfs_drive_unref (drive);
@@ -1473,6 +1477,24 @@ _gnome_vfs_hal_mounts_modify_volume (GnomeVFSVolumeMonitorDaemon *volume_monitor
 	 */
 	hal_drive = libhal_drive_from_device_file (hal_ctx, volume->priv->device_path);
 	if (hal_drive != NULL) {
+
+		/* handle drives that HAL can't poll and the user can still mount */
+		if (libhal_device_get_property_bool (hal_ctx, 
+						     libhal_drive_get_udi (hal_drive),
+						     "storage.media_check_enabled",
+						     NULL) == FALSE) {
+			GnomeVFSDrive *drive;
+
+			if ((drive = _gnome_vfs_volume_monitor_find_drive_by_hal_udi (
+				     GNOME_VFS_VOLUME_MONITOR (volume_monitor_daemon),
+				     libhal_drive_get_udi (hal_drive))) != NULL) {
+				volume->priv->drive = drive;
+				_gnome_vfs_drive_add_mounted_volume (drive, volume);
+				
+				goto out;
+			}
+		}
+
 		/* ok, this device file is in HAL and thus managed by this backend */
 		gnome_vfs_volume_unref (volume);
 		result = NULL;
