@@ -51,7 +51,11 @@ typedef void (*XdgMimeDestroy)  (void *user_data);
 #define xdg_mime_get_mime_type_from_file_name XDG_ENTRY(get_mime_type_from_file_name)
 #define xdg_mime_is_valid_mime_type           XDG_ENTRY(is_valid_mime_type)
 #define xdg_mime_mime_type_equal              XDG_ENTRY(mime_type_equal)
+#define xdg_mime_media_type_equal             XDG_ENTRY(media_type_equal)
 #define xdg_mime_mime_type_subclass           XDG_ENTRY(mime_type_subclass)
+#define xdg_mime_get_mime_parents             XDG_ENTRY(get_mime_parents)
+#define xdg_mime_list_mime_parents            XDG_ENTRY(list_mime_parents)
+#define xdg_mime_unalias_mime_type            XDG_ENTRY(unalias_mime_type)
 #define xdg_mime_get_max_buffer_extents       XDG_ENTRY(get_max_buffer_extents)
 #define xdg_mime_shutdown                     XDG_ENTRY(shutdown)
 #define xdg_mime_register_reload_callback     XDG_ENTRY(register_reload_callback)
@@ -62,24 +66,32 @@ typedef void (*XdgMimeDestroy)  (void *user_data);
 extern const char *xdg_mime_type_unknown;
 #define XDG_MIME_TYPE_UNKNOWN xdg_mime_type_unknown
 
-const char *xdg_mime_get_mime_type_for_data       (const void *data,
-						   size_t      len);
-const char *xdg_mime_get_mime_type_for_file       (const char *file_name);
-const char *xdg_mime_get_mime_type_from_file_name (const char *file_name);
-int         xdg_mime_is_valid_mime_type           (const char *mime_type);
-int         xdg_mime_mime_type_equal              (const char *mime_a,
-						   const char *mime_b);
-int         xdg_mime_media_type_equal             (const char *mime_a,
-						   const char *mime_b);
-int         xdg_mime_mime_type_subclass           (const char *mime_a,
-						   const char *mime_b);
-int         xdg_mime_get_max_buffer_extents       (void);
-void        xdg_mime_shutdown                     (void);
-void        xdg_mime_dump                         (void);
-int         xdg_mime_register_reload_callback     (XdgMimeCallback  callback,
-						   void            *data,
-						   XdgMimeDestroy   destroy);
-void        xdg_mime_remove_callback              (int              callback_id);
+const char  *xdg_mime_get_mime_type_for_data       (const void *data,
+						    size_t      len);
+const char  *xdg_mime_get_mime_type_for_file       (const char *file_name);
+const char  *xdg_mime_get_mime_type_from_file_name (const char *file_name);
+int          xdg_mime_is_valid_mime_type           (const char *mime_type);
+int          xdg_mime_mime_type_equal              (const char *mime_a,
+						    const char *mime_b);
+int          xdg_mime_media_type_equal             (const char *mime_a,
+						    const char *mime_b);
+int          xdg_mime_mime_type_subclass           (const char *mime_a,
+						    const char *mime_b);
+  /* xdg_mime_get_mime_parents() is deprecated since it does
+   * not work correctly with caches. Use xdg_mime_list_parents() 
+   * instead, but notice that that function expects you to free
+   * the array it returns. 
+   */
+const char **xdg_mime_get_mime_parents		   (const char *mime);
+char **      xdg_mime_list_mime_parents		   (const char *mime);
+const char  *xdg_mime_unalias_mime_type		   (const char *mime);
+int          xdg_mime_get_max_buffer_extents       (void);
+void         xdg_mime_shutdown                     (void);
+void         xdg_mime_dump                         (void);
+int          xdg_mime_register_reload_callback     (XdgMimeCallback  callback,
+						    void            *data,
+						    XdgMimeDestroy   destroy);
+void         xdg_mime_remove_callback              (int              callback_id);
 
 #ifdef __cplusplus
 }
